@@ -8,14 +8,13 @@
 # Software Foundation; either version 2.1 of the License, or (at your option)
 # any later version.
 #
-# Paramiko is distrubuted in the hope that it will be useful, but WITHOUT ANY
+# Paramiko is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 # A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA.
+# along with Paramiko; if not, see <https://www.gnu.org/licenses/>.
 
 """
 Sample script showing how to do local port forwarding over paramiko.
@@ -25,8 +24,6 @@ forwarding (the openssh -L option) from a local port through a tunneled
 connection to a destination reachable from the SSH server machine.
 """
 
-from __future__ import print_function
-
 import logging
 import select
 import socketserver
@@ -49,24 +46,22 @@ class Handler(socketserver.BaseRequestHandler):
             )
         except Exception as e:
             logger.debug(
-                'Incoming request to %s:%d failed: %s'
-                % (self.chain_host, self.chain_port, repr(e))
+                'Incoming request to %s:%d failed: %r',
+                self.chain_host,
+                self.chain_port,
+                e,
             )
             return
         if chan is None:
             logger.debug(
-                'Incoming request to %s:%d was rejected by the SSH server.'
-                % (self.chain_host, self.chain_port)
+                'Incoming request to %s:%d was rejected by the SSH server.',
+                self.chain_host,
+                self.chain_port,
             )
             return
 
         logger.debug(
-            'Connected!  Tunnel open %r -> %r -> %r'
-            % (
-                self.request.getpeername(),
-                chan.getpeername(),
-                (self.chain_host, self.chain_port),
-            )
+            f'Connected!  Tunnel open {self.request.getpeername()!r} -> {chan.getpeername()!r} -> {(self.chain_host, self.chain_port)!r}'
         )
         while True:
             r, w, x = select.select([self.request, chan], [], [])
